Analytics class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

configuration Configuration
no setter

Static Methods

clearInternalData() Future<void>
Clears internal data
clearOfflineCache() Future<void>
Clears offline cache
flushOfflineCache() Future<void>
Flushes offline cached measurements.
getLogLevel() Future<ComScoreLogLevel?>
Returns the ComScore log level. @see ComScoreLogLevel @return ComScore log level
getVersion() Future<String?>
Gets the ComScore SDK version.
notifyDistributedContentViewEvent(String distributorPartnerId, String distributorContentId) Future<void>
Notifies about distributed content view event @param distributorPartnerId Distributed partner ID @param distributorContentId Distributed content ID
notifyEnterForeground() Future<void>
Notifies that an application is in the foreground. Several application components can be notified in the foreground because several calls to this methods are stacked but each of these application components should be unstacked when they exit foreground by calling notifyExitForeground().
notifyExitForeground() Future<void>
Notifies that an application exists the foreground state. Several application components can be notified in the foreground because several calls to this methods are stacked but each of these application components should be unstacked when they exit foreground by calling notifyEnterForeground().
notifyHiddenEvent({EventInfo? eventInfo, Map<String, String>? labels}) Future<void>
Notifies in a background thread a hidden event using the EventInfo object. The labels passed in the EventInfo will override any sdk or persistent label.
notifyUxActive() Future<void>
Call this method to notify that the application is executing a task that provides a user experience (e.g. playing music). Several calls to this method are stacked so multiple user experience tasks can be notified but each task should be unstacked using notifyUxInactive.
notifyUxInactive() Future<void>
Call this method to notify that the application finished executing a task that provides a user experience (e.g. playing music). If several user experience tasks were notified using notifyUxActive(). each of those tasks should notify they ended by calling this method. If no user experience tasks were notified using notifyUxActive() then calling this method has no effect. All
notifyViewEvent({EventInfo? eventInfo, Map<String, String>? labels}) Future<void>
Notifies in a background thread a view event using the EventInfo object. The labels passed in the EventInfo will override any sdk or persistent label.
setLogLevel(ComScoreLogLevel level) Future<void>
Change the log level of the comScore SDK. to define the logging level.
start() Future<void>
Start the ComScore SDK with the default configuration. The startup logic will take place in a background thread. @param context Required context to initialize the SDK