notifyEnterForeground static method

Future<void> notifyEnterForeground()

Notifies that an application is in the foreground. Several application components can be notified in the foreground because several calls to this methods are stacked but each of these application components should be unstacked when they exit foreground by calling notifyExitForeground().

Implementation

static Future<void> notifyEnterForeground() {
  return _methodChannel.invokeMethod<void>('notifyEnterForeground');
}