notifyExitForeground static method

Future<void> notifyExitForeground()

Notifies that an application exists the foreground state. Several application components can be notified in the foreground because several calls to this methods are stacked but each of these application components should be unstacked when they exit foreground by calling notifyEnterForeground().

Implementation

static Future<void> notifyExitForeground() {
  return _methodChannel.invokeMethod<void>('notifyExitForeground');
}