notifyUxActive static method

Future<void> notifyUxActive()

Call this method to notify that the application is executing a task that provides a user experience (e.g. playing music). Several calls to this method are stacked so multiple user experience tasks can be notified but each task should be unstacked using notifyUxInactive.

Implementation

static Future<void> notifyUxActive() {
  return _methodChannel.invokeMethod<void>('notifyUxActive');
}