notifyViewEvent static method
Notifies in a background thread a view event using the EventInfo object. The labels passed in the EventInfo will override any sdk or persistent label.
@param eventInfo Information to send in the event. @param labels Labels that should be added to the event.
Implementation
static Future<void> notifyViewEvent({EventInfo? eventInfo, Map<String, String>? labels}) {
var args = <String, dynamic>{Args.eventInfoRefId: eventInfo?.refId, Args.labels: labels};
return _methodChannel.invokeMethod<void>('notifyViewEvent', args);
}