setPersistentLabel method

Future<void> setPersistentLabel(
  1. String labelName,
  2. String labelValue
)

Sets a persistent label. If the label already exists it will be overridden with the new value and if the provided value is null the label will be removed. Persistent labels are included in all further events. Persistent labels overrides sdk labels but they can be overridden by event labels. @param name Label name @param value Label value to be set

Implementation

Future<void> setPersistentLabel(String labelName, String labelValue) {
  var args = buildArguments();
  args[Args.labelName] = labelName;
  args[Args.labelValue] = labelValue;
  return _methodChannel.invokeMethod('setPersistentLabel', args);
}