Configuration class

Constructors

Configuration.private()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addClient(ClientConfiguration? client) Future<void>
addCrossPublisherUniqueDeviceIdChangeListener(OnCrossPublisherUniqueDeviceIdChange callback) → void
addIncludedPublisher(String publisherId) Future<void>
Adds an included publisher. @param publisherId Publisher ID
addPersistentLabels(Map<String, String> labels) Future<void>
Adds a group of persistent labels. Persistent labels are included in all further events. Persistent labels overrides sdk labels but can be overridden by event labels. @param labels Labels to be set
addStartLabels(Map<String, String> labels) Future<void>
Adds a group of start labels. Persistent labels are included in all further events. Persistent labels overrides sdk labels but can be overridden by event labels. @param labels Labels
disable() Future<void>
Disables the Core. No measurements will be sent and no data will be collected.
disableTcfIntegration() Future<void>
Disables TCF integration.
enableChildDirectedApplicationMode() Future<void>
Enables child directed application mode.
enableImplementationValidationMode() Future<void>
getLabelOrder() Future<List<String>?>
Returns a copy of the label order used when sending events. @return Copy of the labels order.
getPartnerConfiguration(String partnerId) Future<PartnerConfiguration?>
Returns the PartnerConfiguration object for the specific partner ID @param partnerId Partner ID to retrieve. @return The PartnerConfiguration representing the partner ID or null if it does not exist
getPartnerConfigurations() Future<List<PartnerConfiguration>>
Returns all PartnerConfiguration objects @return List of all PartnerConfiguration objects
getPublisherConfiguration(String publisherId) Future<PublisherConfiguration?>
Returns the PublisherConfiguration object for the specific publisher ID @param publisherId Publisher ID to retrieve. @return The PublisherConfiguration representing the publisher ID or null if it does not exist
getPublisherConfigurations() Future<List<PublisherConfiguration>>
Returns all PublisherConfiguration objects @return List of all PublisherConfiguration objects
isEnabled() Future<bool?>
Indicates if tracking is enabled. When tracking is disabled, no measurement is sent and no data is collected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPersistentLabels() Future<void>
Removes all the persistent labels in this configuration.
removeAllStartLabels() Future<void>
Removes all the start labels in this configuration.
removeCrossPublisherUniqueDeviceIdChangeListener(OnCrossPublisherUniqueDeviceIdChange callback) → void
removePersistentLabel(String name) Future<void>
Removes an specific persistent label using the name. @param name Name of the label to remove
removeStartLabel(String name) Future<void>
Removes an specific start label using the name. @param name Name of the label to remove
setApplicationName(String appName) Future<void>
Sets the application name. On some platforms like Android and iOS this information is retrieved automatically. @param appName Application name
setApplicationVersion(String appVersion) Future<void>
Sets the application version. On some platforms like Android and iOS this information is retrieved automatically. @param appVersion Application version
setCacheMaxBatchFiles(int max) Future<void>
Sets the maximum amount of measurements can be cached in a single file. This is only available for Android and iOS @param max Amount of measurements
setCacheMaxFlushesInARow(int max) Future<void>
Sets the maximum amount flushes of cached measurements can be send in a row. @param max Maximum amount of flushed to be send
setCacheMaxMeasurements(int max) Future<void>
Sets the maximum amount of measurements that can be cached. @param max Amount of measurements
setCacheMeasurementExpiry(int days) Future<void>
Sets the time after which the measurements in the cache should expire. @param days Days to keep cached measurements.
setCacheMinutesToRetry(int minutes) Future<void>
Sets the minimal time between cache flush retries, in case of failure. @param minutes Minutes to wait.
setKeepAliveMeasurementEnabled(bool enabled) Future<void>
Enables or disables the keep alive option. @param enabled Keep alive
setLabelOrder(List<String> labelOrder) Future<void>
Sets the label order used while sending events. The labels are sorted following the specified order. If the order doesn't specify a label then that label will be added at the end not following any order. @param labelOrder Label order to follow when sending the event
setLiveEndpointUrl(String liveEndpointUrl) Future<void>
Sets the live end point URL. @param liveEndpointUrl Live Endpoint URL
setLiveTransmissionMode(LiveTransmissionMode liveTransmissionMode) Future<void>
Sets the transmission mode. There are 3 modes:
setOfflineCacheMode(OfflineCacheMode offlineCacheMode) Future<void>
Sets the offline cache mode. There are 3 modes:
setOfflineFlushEndpointUrl(String offlineFlushEndpointUrl) Future<void>
Sets the offline flush end point URL. @param offlineFlushEndpointUrl Offline flush endpoint URL
setPersistentLabel(String name, String value) Future<void>
Sets a persistent label. If the label exist it will override it with the new value and if the value is null the label will be removed. Persistent labels are included in all further events. Persistent labels overrides sdk labels but can be overridden by event labels. @param name Label name @param value Label value
setStartLabel(String name, String value) Future<void>
Sets a start label. If the label exist it will override it with the new value and if the value is null the label will be removed. Persistent labels are included in all further events. Persistent labels overrides sdk labels but can be overridden by event labels. @param name Label name @param value Label value
setSystemClockJumpDetectionEnabled(bool enabled) Future<void>
Sets the System Clock Jump Detection. @param isEnabled Set to true to enable, false to disable
setSystemClockJumpDetectionInterval(int interval) Future<void>
Sets the system clock jump detection interval. @param interval Check interval in seconds
setSystemClockJumpDetectionPrecision(int precision) Future<void>
Sets the system clock jump detection precision. @param precision Precision
setUsagePropertiesAutoUpdateInterval(int interval) Future<void>
Sets the the auto update of usage properties interval in seconds. The interval should be bigger or equal to 60. @param interval Interval in seconds
setUsagePropertiesAutoUpdateMode(UsagePropertiesAutoUpdateMode usagePropertiesAutoUpdateMode) Future<void>
UsagePropertiesAutoUpdateMode.foregroundOnly by default. @param usagePropertiesAutoUpdateMode Auto update mode for properties usage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited