disable method
Disables the Core. No measurements will be sent and no data will be collected.
Implementation
Future<void> disable() {
return methodChannel.invokeMethod('disable');
}
Disables the Core. No measurements will be sent and no data will be collected.
Future<void> disable() {
return methodChannel.invokeMethod('disable');
}