PartnerConfiguration class

Inheritance
Available extensions

Constructors

PartnerConfiguration.init(String refId)

Properties

hashCode int
The hash code for this object.
no setterinherited
refId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPersistentLabels(Map<String, String> labels) Future<void>
Adds a group of persistent labels. Persistent labels are included in all further events. Persistent labels overrides sdk labels but can be overridden by event labels. @param labels Map of labels
inherited
buildArguments() Map<String, dynamic>

Available on TrackableObject, provided by the TrackableObjectExtension extension

containsPersistentLabel(String labelName) Future<bool?>
Returns true if the there's a label with the given name.
inherited
containsStartLabel(String labelName) Future<bool?>
Returns true if the there's a label with the given name.
inherited
getClientId(ClientConfigurationType type) Future<String?>
inherited
getPartnerId() Future<String?>
Returns the partner ID.
getPersistentLabel(String labelName) Future<String?>
Returns the value of the specified label. If more than one label needs to be checked use ClientConfiguration#getPersistentLabels() to retrieve multiple labels. @param labelName Label name to retrieve the value @return The label name value
inherited
getPersistentLabels() Future<Map<String, String>?>
Returns a copy of the persistent labels in use @return Copy of the persistent labels
inherited
getStartLabels() Future<Map<String, String>?>
Returns a copy of the auto start labels in use. @return Copy of auto start labels
inherited
isHttpRedirectCachingEnabled() Future<bool?>
Indicates if http redirects should be cached or not.
inherited
isKeepAliveMeasurementEnabled() Future<bool?>
Returns if the keep alive is enabled. @return True if keep alive is enabled, false otherwise
inherited
isSecureTransmissionEnabled() Future<bool?>
Returns the secure mode value. @return True if is enabled, false otherwise
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPersistentLabels() Future<void>
Removes all the persistent labels in this configuration.
inherited
removePersistentLabel(String name) Future<void>
Removes an specific persistent label using the name. @param name Name of the label to remove
inherited
setPersistentLabel(String labelName, String labelValue) Future<void>
Sets a persistent label. If the label already exists it will be overridden with the new value and if the provided value is null the label will be removed. Persistent labels are included in all further events. Persistent labels overrides sdk labels but they can be overridden by event labels. @param name Label name @param value Label value to be set
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required String partnerId, bool? httpRedirectCaching, bool? keepAliveMeasurement, bool? secureTransmission, Map<String, String>? persistentLabels, Map<String, String>? startLabels, String? externalClientId}) Future<PartnerConfiguration?>