AdvertisementMetadata class

Inheritance

Properties

breakNumber int?
Used to populate label ns_st_bn
final
callToActionUrl String?
Used to populate label ns_st_amc
final
classifyAsAudioStream bool?
Used to populate labels ns_st_ct and ns_st_ty
final
clipUrl String?
Used to populate label ns_st_cu
final
customLabels Map<String, String>
final
deliveryType AdvertisementDeliveryType?
final
fee int?
Used to populate label ns_st_fee
final
hashCode int
The hash code for this object.
no setterinherited
length int?
Used to populate label ns_st_cl
final
mediaType AdvertisementType?
Used to populate labels ns_st_ct, ns_st_li and ns_st_ad
final
numberInBreak int?
Used to populate label ns_st_an
final
owner AdvertisementOwner?
final
placementId String?
Used to populate label ns_st_amp
final
relatedContentMetadata ContentMetadata?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server String?
Used to populate label ns_st_ams
final
serverCampaignId String?
Used to populate label ns_st_amg
final
siteId String?
Used to populate label ns_st_amw
final
stack Map<String, StackedAdvertisementMetadata>
final
title String?
Used to populate label ns_st_amt
final
totalBreaks int?
Used to populate label ns_st_tb
final
totalInBreak int?
Used to populate label ns_st_ta
final
uniqueId String?
Used to populate label ns_st_ami
final
videoDimensions Dimensions?
Used to populate label ns_st_cs
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

builder() AdvertisementMetadataBuilder