StackedAdvertisementMetadata class

Inheritance

Constructors

StackedAdvertisementMetadata({Map<String, String>? customLabels, int? fee, String? uniqueId, String? title, String? serverCampaignId, String? placementId, String? siteId})

Properties

fee int?
Used to populate label ns_st_fee
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
final
placementId String?
Used to populate label ns_st_amp
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverCampaignId String?
Used to populate label ns_st_amg
final
siteId String?
Used to populate label ns_st_amw
final
title String?
Used to populate label ns_st_amt
final
uniqueId String?
Used to populate label ns_st_ami
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited