notifyCallToAction method

Future<void> notifyCallToAction([
  1. Map<String, String>? labels
])

Notifies of a new Call to Action event with associated labels.

@param labels map of labels associated with the current event

Implementation

Future<void> notifyCallToAction([Map<String, String>? labels]) {
  var args = buildArguments();
  args[Args.labels] = labels;
  return _methodChannel.invokeMethod<void>('notifyCallToAction', args);
}