StreamingPublisherConfiguration class

Inheritance
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
refId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLabels(Map<String, String> labels) Future<void>
buildArguments() Map<String, dynamic>

Available on TrackableObject, provided by the TrackableObjectExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllLabels() Future<void>
removeLabel(String name) Future<void>
setLabel(String name, String value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited