StreamingState enum

Inheritance
Available extensions

Values

undefined → const StreamingState
const StreamingState(-1)
idle → const StreamingState
const StreamingState(0)
playbackNotStarted → const StreamingState
const StreamingState(1)
playing → const StreamingState
const StreamingState(2)
paused → const StreamingState
const StreamingState(3)
bufferingBeforePlayback → const StreamingState
const StreamingState(4)
bufferingDuringPlayback → const StreamingState
const StreamingState(5)
bufferingDuringSeeking → const StreamingState
const StreamingState(6)
bufferingDuringPause → const StreamingState
const StreamingState(7)
seekingBeforePlayback → const StreamingState
const StreamingState(8)
seekingDuringPlayback → const StreamingState
const StreamingState(9)
seekingDuringBuffering → const StreamingState
const StreamingState(10)
seekingDuringPause → const StreamingState
const StreamingState(11)
pauseDuringBuffering → const StreamingState
const StreamingState(12)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByValue(num i) StreamingState

Constants

values → const List<StreamingState>
A constant List of the values in this enum, in order of their declaration.