UsagePropertiesAutoUpdateMode enum

Inheritance
Available extensions

Values

disabled → const UsagePropertiesAutoUpdateMode

Usage properties will not auto update.

const UsagePropertiesAutoUpdateMode(20502)
foregroundAndBackground → const UsagePropertiesAutoUpdateMode

Usage properties will auto update in foreground and background.

const UsagePropertiesAutoUpdateMode(20501)
foregroundOnly → const UsagePropertiesAutoUpdateMode

Usage properties will auto update only while in foreground.

const UsagePropertiesAutoUpdateMode(20500)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mode int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UsagePropertiesAutoUpdateMode>
A constant List of the values in this enum, in order of their declaration.