Notifies that an application is in the foreground. Several application components
can be notified in the foreground because several calls to this methods are stacked but each
of these application components should be unstacked when they exit foreground by calling
notifyExitForeground().
Notifies that an application exists the foreground state. Several application components
can be notified in the foreground because several calls to this methods are stacked but each
of these application components should be unstacked when they exit foreground by calling
notifyEnterForeground().
Notifies in a background thread a hidden event using the EventInfo object.
The labels passed in the EventInfo will override any sdk or persistent
label.
Call this method to notify that the application is executing a task that provides a user
experience (e.g. playing music). Several calls to this method are stacked so multiple user
experience tasks can be notified but each task should be unstacked using
notifyUxInactive.
Call this method to notify that the application finished executing a task that provides a
user experience (e.g. playing music). If several user experience tasks were notified using
notifyUxActive(). each of those tasks should notify they ended by calling
this method. If no user experience tasks were notified using notifyUxActive()
then calling this method has no effect. All
Start the ComScore SDK with the default configuration. The startup logic will take place in
a background thread.
@param context Required context to initialize the SDK