notifyUxInactive static method
Call this method to notify that the application finished executing a task that provides a user experience (e.g. playing music). If several user experience tasks were notified using notifyUxActive(). each of those tasks should notify they ended by calling this method. If no user experience tasks were notified using notifyUxActive() then calling this method has no effect. All
Implementation
static Future<void> notifyUxInactive() {
return _methodChannel.invokeMethod<void>('notifyUxInactive');
}