start static method
Start the ComScore SDK with the default configuration. The startup logic will take place in a background thread. @param context Required context to initialize the SDK
Implementation
static Future<void> start() async {
Analytics.configuration.setPersistentLabel("ns_ap_cv", Connector.version);
Analytics.configuration.setPersistentLabel("ns_ap_pfm", Connector.platformName);
// Analytics.configuration.setPersistentLabel("ns_ap_pv", ); // It is not possible to retrieve the flutter version
await _methodChannel.invokeMethod<void>('start');
}