setCacheMaxFlushesInARow method
Sets the maximum amount flushes of cached measurements can be send in a row. @param max Maximum amount of flushed to be send
Implementation
Future<void> setCacheMaxFlushesInARow(int max) {
return methodChannel.invokeMethod('setCacheMaxFlushesInARow', {Args.max: max});
}