EventInfo class
- Inheritance
-
- Object
- TrackableObject
- EventInfo
- Available extensions
Properties
Methods
-
addIncludedPublisher(
String publisherId) → Future< void> - Adds a publisher if it doesn't exist. @param publisherId Publisher ID to add
-
addLabels(
Map< String, String> labels) → Future<void> - Adds a dictionary as labels for the event. These labels will be sent for all the specified publishers. @param labels Labels to add
-
addPublisherLabels(
String publisherId, Map< String, String> labels) → Future<void> - Adds a publisher specific labels. This labels will be only associated with the specified publisher. @param publisherId Publisher ID @param labels Labels to add
-
buildArguments(
) → Map< String, dynamic> -
Available on TrackableObject, provided by the TrackableObjectExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLabel(
String name, String value) → Future< void> - Sets a label for the event. This label will be sent for all the specified publishers. @param name Label name @param value Label value
-
setPublisherLabel(
String publisherId, String name, String value) → Future< void> - Sets a publisher specific label. This labels will be only associated with the specified publisher. @param publisherId Publisher ID @param name Label name @param value Label value
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited