LiveTransmissionMode enum
Values
- cache → const LiveTransmissionMode
-
The Events are requested to be stored in the OfflineCache even if a network connection is available.
const LiveTransmissionMode(20003) - lan → const LiveTransmissionMode
-
Only sends Events if the device is connected to a local area network (for instance: wifi or ethernet), otherwise the Events are requested to be stored in the OfflineCache.
const LiveTransmissionMode(20002) - standard → const LiveTransmissionMode
-
Standard behavior. It will send the Events if there is a network connection.
const LiveTransmissionMode(20001)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mode → int
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
LiveTransmissionMode> - A constant List of the values in this enum, in order of their declaration.