OfflineCacheMode enum
Values
- disabled → const OfflineCacheMode
-
The OfflineCache will not store any event nor send any event.
const OfflineCacheMode(20104) - lan → const OfflineCacheMode
-
Only flushing the cache is allowed if the device is connected to a local area network. (for instance: wifi or ethernet).
const OfflineCacheMode(20103) - enabled → const OfflineCacheMode
-
Normal behavior. It will store and flush automatically the events in the cache.
const OfflineCacheMode(20101) - manualFlush → const OfflineCacheMode
-
The OfflineCache is not flushed automatically. To flush it call OfflineCache#flush() manually.
const OfflineCacheMode(20102)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mode → int
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
OfflineCacheMode> - A constant List of the values in this enum, in order of their declaration.