ContentDeliveryAdvertisementCapability enum
Values
- none → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(801) - dynamicLoad → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(802) - dynamicReplacement → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(803) - linear1Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(804) - linear2Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(805) - linear3Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(806) - linear4Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(807) - linear5Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(808) - linear6Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(809) - linear7Day → const ContentDeliveryAdvertisementCapability
-
const ContentDeliveryAdvertisementCapability(810)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
ContentDeliveryAdvertisementCapability> - A constant List of the values in this enum, in order of their declaration.