ContentMetadata class
- Inheritance
-
- Object
- AssetMetadata
- ContentMetadata
Properties
- carryTvAdvertisementLoad → bool?
-
Used to populate label ns_st_ia
final
- classifyAsAudioStream → bool?
-
Used to populate labels ns_st_ct and ns_st_ty
final
- classifyAsCompleteEpisode → bool?
-
Used to populate label ns_st_ce
final
- clipUrl → String?
-
Used to populate label ns_st_cu
final
-
customLabels
→ Map<
String, String> -
final
- deliveryAdvertisementCapability → ContentDeliveryAdvertisementCapability?
-
final
- deliveryComposition → ContentDeliveryComposition?
-
final
- deliveryMode → ContentDeliveryMode?
-
final
- deliverySubscriptionType → ContentDeliverySubscriptionType?
-
final
- dictionaryClassificationC3 → String?
-
final
- dictionaryClassificationC4 → String?
-
final
- dictionaryClassificationC6 → String?
-
final
- digitalAiringDate → Date?
-
Used to populate label ns_st_ddt
final
- digitalAiringTime → Time?
-
Used to populate label ns_st_dtm
final
- distributionModel → ContentDistributionModel?
-
final
- episodeId → String?
-
Used to populate label ns_st_tep
final
- episodeNumber → String?
-
Used to populate label ns_st_en
final
- episodeSeasonNumber → String?
-
Used to populate label ns_st_sn
final
- episodeTitle → String?
-
Used to populate label ns_st_ep
final
- fee → int?
-
Used to populate label ns_st_fee
final
- feedType → ContentFeedType?
-
Used to populate label ns_st_ft
final
- genreId → String?
-
Used to populate label ns_st_tge
final
- genreName → String?
-
Used to populate label ns_st_ge
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int?
-
Used to populate label ns_st_cl
final
- mediaFormat → ContentMediaFormat?
-
final
- mediaType → ContentType?
-
Used to populate labels ns_st_ct and ns_st_li
final
- networkAffiliate → String?
-
Used to populate label ns_st_sta
final
- playlistTitle → String?
-
Used to populate label ns_st_pl
final
- productionDate → Date?
-
Used to populate label ns_st_dt
final
- productionTime → Time?
-
Used to populate label ns_st_tm
final
- programId → String?
-
Used to populate label ns_st_tpr
final
- programTitle → String?
-
Used to populate label ns_st_pr
final
- publisherName → String?
-
Used to populate label ns_st_pu
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stack
→ Map<
String, StackedContentMetadata> -
final
- stationCode → String?
-
Used to populate label ns_st_stc
final
- stationTitle → String?
-
Used to populate label ns_st_st
final
- totalSegments → int?
-
Used to populate label ns_st_tp
final
- tvAiringDate → Date?
-
Used to populate label ns_st_tdt
final
- tvAiringTime → Time?
-
Used to populate label ns_st_ttm.
final
- uniqueId → String?
-
Used to populate label ns_st_ci
final
- videoDimensions → Dimensions?
-
Used to populate label ns_st_cs
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited