StackedContentMetadata class
- Inheritance
-
- Object
- StackedMetadata
- StackedContentMetadata
Constructors
-
StackedContentMetadata({Map<
String, String> ? customLabels, String? uniqueId, String? publisherName, String? programTitle, String? episodeTitle, String? episodeSeasonNumber, String? episodeNumber, String? genreName, String? genreId, Date? productionDate, Time? productionTime, Date? digitalAiringDate, Time? digitalAiringTime, Date? tvAiringDate, Time? tvAiringTime, String? stationTitle, String? stationCode, String? programId, String? episodeId, String? networkAffiliate, int? fee, String? playlistTitle, String? dictionaryClassificationC3, String? dictionaryClassificationC4, String? dictionaryClassificationC6, ContentDeliveryMode? deliveryMode, ContentDeliverySubscriptionType? deliverySubscriptionType, ContentDeliveryComposition? deliveryComposition, ContentDeliveryAdvertisementCapability? deliveryAdvertisementCapability, ContentDistributionModel? distributionModel, ContentMediaFormat? mediaFormat})
Properties
- deliveryAdvertisementCapability ↔ ContentDeliveryAdvertisementCapability?
-
getter/setter pair
- deliveryComposition ↔ ContentDeliveryComposition?
-
getter/setter pair
- deliveryMode ↔ ContentDeliveryMode?
-
getter/setter pair
- deliverySubscriptionType ↔ ContentDeliverySubscriptionType?
-
getter/setter pair
- dictionaryClassificationC3 → String?
-
final
- dictionaryClassificationC4 → String?
-
final
- dictionaryClassificationC6 → String?
-
final
- digitalAiringDate → Date?
-
Used to populate label ns_st_ddt
final
- digitalAiringTime → Time?
-
Used to populate label ns_st_dtm.
final
- distributionModel ↔ ContentDistributionModel?
-
getter/setter pair
- episodeId → String?
-
Used to populate label ns_st_tep
final
- episodeNumber → String?
-
Used to populate label ns_st_en
final
- episodeSeasonNumber → String?
-
Used to populate label ns_st_sn
final
- episodeTitle → String?
-
Used to populate label ns_st_ep
final
- fee → int?
-
Used to populate label ns_st_fee
final
- genreId → String?
-
Used to populate label ns_st_tge
final
- genreName → String?
-
Used to populate label ns_st_ge
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> ? -
final
- mediaFormat ↔ ContentMediaFormat?
-
getter/setter pair
- networkAffiliate → String?
-
Used to populate label ns_st_sta
final
- playlistTitle → String?
-
Used to populate label ns_st_pl
final
- productionDate → Date?
-
Used to populate label ns_st_dt
final
- productionTime → Time?
-
Used to populate label ns_st_tm
final
- programId → String?
-
Used to populate label ns_st_tpr
final
- programTitle → String?
-
Used to populate label ns_st_pr
final
- publisherName → String?
-
Used to populate label ns_st_pu
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stationCode → String?
-
Used to populate label ns_st_stc
final
- stationTitle → String?
-
Used to populate label ns_st_st
final
- tvAiringDate → Date?
-
Used to populate label ns_st_tdt
final
- tvAiringTime → Time?
-
Used to populate label ns_st_ttm
final
- uniqueId → String?
-
Used to populate label ns_st_ci
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited