StreamingAnalytics class
- Inheritance
-
- Object
- TrackableObject
- StreamingAnalytics
- Available extensions
Properties
- configuration → StreamingConfiguration?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- refId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
OnStreamingStateChange listener) → Future< void> - Adds a new listener to be notified of changes of states.
-
buildArguments(
) → Map< String, dynamic> -
Available on TrackableObject, provided by the TrackableObjectExtension extension
-
createPlaybackSession(
) → Future< void> - Sets a new playback session.
-
getExtendedAnalytics(
) → Future< StreamingExtendedAnalytics?> -
getPlaybackSessionId(
) → Future< String?> - Returns Playback session ID @return Playback session ID
-
loopPlaybackSession(
) → Future< void> - Notifies about looping playback session
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyBufferStart(
) → Future< void> - Notifies of a new Buffer Start event.
-
notifyBufferStop(
) → Future< void> - Notifies of a new Buffer End event.
-
notifyChangePlaybackRate(
double rate) → Future< void> - Clears offline cache
-
notifyEnd(
) → Future< void> - Notifies of a new End event.
-
notifyPause(
) → Future< void> - Notifies of a new Pause event.
-
notifyPlay(
) → Future< void> - Notifies of a new Play event.
-
notifySeekStart(
) → Future< void> - Returns the ComScore log level. @see ComScoreLogLevel @return ComScore log level
-
removeListener(
OnStreamingStateChange listener) → Future< void> - Removes the given listener
-
setDvrWindowLength(
int newDvrWindowLength) → Future< void> - Sets the DVR window length.
-
setImplementationId(
String implementationId) → Future< void> - Sets the Implementation ID @param implementationId Implementation ID
-
setMediaPlayerName(
String mediaPlayerName) → Future< void> - Sets the media player name @param mediaPlayerName Media player name
-
setMediaPlayerVersion(
String mediaPlayerVersion) → Future< void> - Sets the media player version @param mediaPlayerVersion Media player version
-
setMetadata(
AssetMetadata metadata) → Future< void> - Sets the asset @param metadata the AssetMetadata instance with the new clip metadata.
-
setProjectId(
String projectId) → Future< void> - Sets the project ID @param projectId Project ID
-
startFromDvrWindowOffset(
int newDvrWindowOffset) → Future< void> - Sets the DVR window offset.
-
startFromPosition(
int position) → Future< void> - Notifies of the start from position @param position Position
-
startFromSegment(
int segmentNumber) → Future< void> - Notifies about start from segment @param segmentNumber Segment Number
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
{List< String> ? includedPublishers, Map<String, String> ? labels, bool? pauseOnBuffering, int? pauseOnBufferingInterval, int? keepAliveInterval, bool? keepAliveMeasurement, List<Map< ? heartbeatIntervals, bool? heartbeatMeasurement, int? customStartMinimumPlayback, bool? autoResumeStateOnAssetChange}) → Future<String, int> >StreamingAnalytics?>