StreamingConfiguration class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addLabels(
Map< String, String> labels) → Future<void> -
getStreamingPublisherConfiguration(
String publisherId) → Future< StreamingPublisherConfiguration?> - Returns StreamingPublisherConfiguration object @param publisherId Publisher ID @return StreamingPublisherConfiguration object
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAllLabels(
) → Future< void> -
removeLabel(
String name) → Future< void> -
setLabel(
String name, String value) → Future< void> - Adds the given label, with the specified value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited