StreamingExtendedAnalytics class
- Inheritance
-
- Object
- TrackableObject
- StreamingExtendedAnalytics
- Available extensions
Constructors
- StreamingExtendedAnalytics(String refId)
Properties
Methods
-
buildArguments(
) → Map< String, dynamic> -
Available on TrackableObject, provided by the TrackableObjectExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyCallToAction(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new Call to Action event with associated labels.
-
notifyChangeAudioTrack(
String newAudio, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change Audio event with the given new audio.
-
notifyChangeBitrate(
int newRate, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change of Bitrate event with the given new rate (in bps).
-
notifyChangeCdn(
String newCDN, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change CDN event with the given new CDN.
-
notifyChangeSubtitleTrack(
String newSubtitle, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change Subtitle event with the given new subtitle.
-
notifyChangeVideoTrack(
String newVideo, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change Video event with the given new video.
-
notifyChangeVolume(
double newVolume, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change Volume event with the given new rate (in percentage, with 100% being max. volume).
-
notifyChangeWindowState(
WindowState newState, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Change Volume event with the given new state.
-
notifyCustomEvent(
String eventName, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Custom streaming event with the associated labels.
-
notifyDrmApprove(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new DRM Approve event. @param labels Labels
-
notifyDrmDeny(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new DRM Deny event. @param labels Labels
-
notifyDrmFail(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new DRM Fail event. @param labels Labels
-
notifyEngage(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new Start event. @param labels Labels
-
notifyError(
String errorIdentifier, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Error event.
-
notifyLoad(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new Load event. @param labels Labels
-
notifySkipAd(
[Map< String, String> ? labels]) → Future<void> - Notifies of a new Skip Ad event. @param labels Labels
-
notifyTransferPlayback(
String targetDevice, [Map< String, String> ? labels]) → Future<void> - Notifies of a new Transfer Playback event.
-
setLoadTimeOffset(
int offset) → Future< void> - Sets the load time offset
-
setPlaybackSessionExpectedLength(
int expectedTotalLength) → Future< void> - Expected total playback session length in milliseconds (sum of asset lengths in playback session).
-
setPlaybackSessionExpectedNumberOfItems(
int expectedNumberOfItems) → Future< void> - Expected total number of assets in playback session (count of individual assets).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited