notifyCustomEvent method
Notifies of a new Custom streaming event with the associated labels.
@param eventName Event name @param labels Map of labels associated with the current event
Implementation
Future<void> notifyCustomEvent(String eventName, [Map<String, String>? labels]) {
var args = buildArguments();
args[Args.labels] = labels;
args["eventName"] = eventName;
return _methodChannel.invokeMethod<void>('notifyCustomEvent', args);
}