Args class abstract
Constructors
- Args()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appId → const String
- appName → const String
- appVersion → const String
- categories → const String
- days → const String
- distributorContentId → const String
- distributorPartnerId → const String
- dkey → const String
- dvrWindow → const String
- enabled → const String
- eventInfoRefId → const String
- implementationId → const String
- interval → const String
- labelName → const String
- labelOrder → const String
- labels → const String
- labelValue → const String
- liveEndpointUrl → const String
- liveTransmissionMode → const String
- max → const String
- mediaPlayerName → const String
- mediaPlayerVersion → const String
- metadata → const String
- minutes → const String
- offlineCacheMode → const String
- offlineFlushEndpointUrl → const String
- partnerId → const String
- position → const String
- precision → const String
- projectId → const String
- publisherId → const String
- publisherUniqueDeviceId → const String
- rate → const String
- refId → const String
- segmentNumber → const String
- type → const String
- url → const String
- usagePropertiesAutoUpdateMode → const String